# -*- coding: utf-8 -*-
"""
Created on Mon Jun 11 15:36:00 2012

@author: John
"""

#import modules
import numpy as np
import glob
import matplotlib.pyplot as plt
import pickle


#Define Parameters
Colors = ['b','g','r','k','m','k','g','r','b']
Symbols = ['o','^','s','x','h','^','s','p','h']


#Get list of all data files
FileList = glob.glob('rho*.pkl')
N = len(FileList)

#Initialize Variables
Cn = np.zeros(N)
Cnerror = np.zeros(N)
rho = np.zeros(N)
T = np.zeros(N)
L = np.zeros(N)
Lambda = np.zeros(N)
plt.close('all')
RDF = []
r = []

#Loop through data files to analyze data
for i in range(N):
    Values = FileList[i].split()
    rho[i] = Values[0][4:]
    T[i] = Values[1][2:]
    Lambda[i] = Values[3][7:]
    
    DataFile = open(FileList[i], 'rb')
    Data = pickle.load(DataFile)
    Cn[i] = np.mean(Data['cN'])
    Cnerror[i] = np.std(Data['cN'])
    L[i] = Data['L']
    RDF.extend([Data['RDF']])
    r.extend([Data['r']])


#plot data in groups of rho
rhoList = list(set(rho))
rhoList.sort()
Nrho = len(rhoList)
TList = list(set(T))
TList.sort()
NT = len(TList)

PlotName = 'cN overall.png'
plt.figure(PlotName)

for i in range(Nrho):
    
    Entry = []

    for ii in range(NT):
    
        indices = [j for j in range(N) if rho[j] == rhoList[i] and
                                    T[j] == TList[ii]]
        subLambda = Lambda[indices]
        subCn = Cn[indices]
        subCnerror = Cnerror[indices]
        
        #plot data
        plt.subplot(2,2,i+1)
        plt.errorbar(subLambda,subCn,yerr=subCnerror,fmt=Colors[ii] + Symbols[ii])
        plt.xlim([-0.5,10.5])
        plt.title('$\\rho$ = %.2g' % (rhoList[i]))
        plt.xlabel('$\lambda$')
        plt.ylabel('Coordination Number')
        Entry.extend(['T = ' + str(TList[ii])])
    
    plt.legend(Entry,numpoints=1,frameon=False)

plt.tight_layout()  
plt.savefig(PlotName) 

PlotName = 'RDF overall.png'
plt.figure(PlotName)

rhoRDF = 0.1
LambdaRDF = [0.0,1.0,2.0,5.0,10.0]
NL = len(LambdaRDF)
    
for ii in range(NT):

    Entry = []
    maxYList = []
    
    for jj in range(NL):
        
        ind = [j for j in range(N) if rho[j] == rhoRDF and
                T[j] == TList[ii] and Lambda[j] == LambdaRDF[jj]]
        ind = ind[0]
        subLambda = Lambda[ind]
    
        #plot data
        plt.subplot(2,2,ii+1)
        plt.plot(r[ind],RDF[ind],Colors[jj],lw=2.0)
        temp = max(RDF[ind][int(1.3/(L[ind]/2.)*1000):])
        maxYList.extend([max([2.0,1.1*temp])])
        plt.title('$\\rho$ = %.2g ; T = %.2g' % (rhoRDF,TList[ii]))
        plt.xlabel('r')
        plt.ylabel('g(r)')
        Entry.extend(['$\lambda$ = ' + str(Lambda[ind])])

    plt.ylim((0.0,max(maxYList)))
    plt.legend(Entry,numpoints=1,frameon=False)

plt.tight_layout()  
plt.savefig(PlotName) 